@@ -45,6 +45,7 @@ var Keys = map[Key]string{
 
 	// tests keys
 	testGetPropertyKey:                                "testGetPropertyKey",
+	testCaseInsensitivePropertyKey:                    "testCaseInsensitivePropertyKey",
 	testGetIntPropertyKey:                             "testGetIntPropertyKey",
 	testGetFloat64PropertyKey:                         "testGetFloat64PropertyKey",
 	testGetDurationPropertyKey:                        "testGetDurationPropertyKey",
@@ -63,7 +64,7 @@ var Keys = map[Key]string{
 	AdminMatchingNamespaceToPartitionDispatchRate:          "admin.matchingNamespaceToPartitionDispatchRate",
 	AdminMatchingNamespaceTaskqueueToPartitionDispatchRate: "admin.matchingNamespaceTaskqueueToPartitionDispatchRate",
 
-	// TODO remove this dynamic flag in 1.12.x
+	// TODO remove this dynamic flag in 1.14.x
 	EnableDBRecordVersion: "system.enableDBRecordVersion",
 
 	// system settings
@@ -76,7 +77,6 @@ var Keys = map[Key]string{
 	EnableReadFromVisibilityArchival:       "system.enableReadFromVisibilityArchival",
 	EnableNamespaceNotActiveAutoForwarding: "system.enableNamespaceNotActiveAutoForwarding",
 	TransactionSizeLimit:                   "system.transactionSizeLimit",
-	MinRetentionDays:                       "system.minRetentionDays",
 	DisallowQuery:                          "system.disallowQuery",
 	EnableBatcher:                          "worker.enableBatcher",
 	EnableParentClosePolicyWorker:          "system.enableParentClosePolicyWorker",
@@ -88,6 +88,8 @@ var Keys = map[Key]string{
 	// size limit
 	BlobSizeLimitError:     "limit.blobSize.error",
 	BlobSizeLimitWarn:      "limit.blobSize.warn",
+	MemoSizeLimitError:     "limit.memoSize.error",
+	MemoSizeLimitWarn:      "limit.memoSize.warn",
 	HistorySizeLimitError:  "limit.historySize.error",
 	HistorySizeLimitWarn:   "limit.historySize.warn",
 	HistoryCountLimitError: "limit.historyCount.error",
@@ -327,6 +329,7 @@ const (
 
 	// key for tests
 	testGetPropertyKey
+	testCaseInsensitivePropertyKey
 	testGetIntPropertyKey
 	testGetFloat64PropertyKey
 	testGetDurationPropertyKey
@@ -345,7 +348,7 @@ const (
 	// AdminMatchingNamespaceTaskqueueToPartitionDispatchRate is the max qps of a task queue partition for a given namespace & task queue
 	AdminMatchingNamespaceTaskqueueToPartitionDispatchRate
 
-	// TODO remove this dynamic flag in 1.12.x
+	// TODO remove this dynamic flag in 1.14.x
 
 	// EnableDBRecordVersion is key for enable db version
 	EnableDBRecordVersion
@@ -373,8 +376,6 @@ const (
 	EnableNamespaceNotActiveAutoForwarding
 	// TransactionSizeLimit is the largest allowed transaction size to persistence
 	TransactionSizeLimit
-	// MinRetentionDays is the minimal allowed retention days for namespace
-	MinRetentionDays
 	// DisallowQuery is the key to disallow query for a namespace
 	DisallowQuery
 	// EnablePriorityTaskProcessor is the key for enabling priority task processor
@@ -387,6 +388,10 @@ const (
 	BlobSizeLimitError
 	// BlobSizeLimitWarn is the per event blob size limit for warning
 	BlobSizeLimitWarn
+	// MemoSizeLimitError is the per event memo size limit
+	MemoSizeLimitError
+	// MemoSizeLimitWarn is the per event memo size limit for warning
+	MemoSizeLimitWarn
 	// HistorySizeLimitError is the per workflow execution history size limit
 	HistorySizeLimitError
 	// HistorySizeLimitWarn is the per workflow execution history size limit for warning
