@@ -159,8 +159,8 @@ func (v *cassandraVisibilityPersistence) RecordWorkflowExecutionStarted(
 		namespacePartition,
 		request.WorkflowID,
 		request.RunID,
-		p.UnixNanoToDBTimestamp(request.StartTimestamp),
-		p.UnixNanoToDBTimestamp(request.ExecutionTimestamp),
+		p.UnixMilliseconds(request.StartTime),
+		p.UnixMilliseconds(request.ExecutionTime),
 		request.WorkflowTypeName,
 		request.Memo.Data,
 		request.Memo.EncodingType.String(),
@@ -169,7 +169,7 @@ func (v *cassandraVisibilityPersistence) RecordWorkflowExecutionStarted(
 	// It is important to specify timestamp for all `open_executions` queries because
 	// we are using milliseconds instead of default microseconds. If custom timestamp collides with
 	// default timestamp, default one will always win because they are 1000 times bigger.
-	query = query.WithTimestamp(p.UnixNanoToDBTimestamp(request.StartTimestamp))
+	query = query.WithTimestamp(p.UnixMilliseconds(request.StartTime))
 	err := query.Exec()
 	return gocql.ConvertError("RecordWorkflowExecutionStarted", err)
 }
@@ -181,7 +181,7 @@ func (v *cassandraVisibilityPersistence) RecordWorkflowExecutionClosed(request *
 	batch.Query(templateDeleteWorkflowExecutionStarted,
 		request.NamespaceID,
 		namespacePartition,
-		p.UnixNanoToDBTimestamp(request.StartTimestamp),
+		p.UnixMilliseconds(request.StartTime),
 		request.RunID,
 	)
 
@@ -201,9 +201,9 @@ func (v *cassandraVisibilityPersistence) RecordWorkflowExecutionClosed(request *
 			namespacePartition,
 			request.WorkflowID,
 			request.RunID,
-			p.UnixNanoToDBTimestamp(request.StartTimestamp),
-			p.UnixNanoToDBTimestamp(request.ExecutionTimestamp),
-			p.UnixNanoToDBTimestamp(request.CloseTimestamp),
+			p.UnixMilliseconds(request.StartTime),
+			p.UnixMilliseconds(request.ExecutionTime),
+			p.UnixMilliseconds(request.CloseTime),
 			request.WorkflowTypeName,
 			request.Status,
 			request.HistoryLength,
@@ -217,9 +217,9 @@ func (v *cassandraVisibilityPersistence) RecordWorkflowExecutionClosed(request *
 			namespacePartition,
 			request.WorkflowID,
 			request.RunID,
-			p.UnixNanoToDBTimestamp(request.StartTimestamp),
-			p.UnixNanoToDBTimestamp(request.ExecutionTimestamp),
-			p.UnixNanoToDBTimestamp(request.CloseTimestamp),
+			p.UnixMilliseconds(request.StartTime),
+			p.UnixMilliseconds(request.ExecutionTime),
+			p.UnixMilliseconds(request.CloseTime),
 			request.WorkflowTypeName,
 			request.Status,
 			request.HistoryLength,
@@ -230,21 +230,21 @@ func (v *cassandraVisibilityPersistence) RecordWorkflowExecutionClosed(request *
 		)
 	}
 
-	// RecordWorkflowExecutionStarted is using StartTimestamp as the timestamp for every query in `open_executions` table.
+	// RecordWorkflowExecutionStarted is using StartTime as the timestamp for every query in `open_executions` table.
 	// Due to the fact that cross DC using mutable state creation time as workflow start time and visibility using event time
-	// instead of last update time (https://github.com/uber/cadence/pull/1501) CloseTimestamp can be before StartTimestamp (or very close it).
-	// In this case, use (StartTimestamp + minWorkflowDuration) for delete operation to guarantee that it is greater than StartTimestamp
+	// instead of last update time (https://github.com/uber/cadence/pull/1501) CloseTime can be before StartTime (or very close it).
+	// In this case, use (StartTime + minWorkflowDuration) for delete operation to guarantee that it is greater than StartTime
 	// and won't be ignored.
 
 	const minWorkflowDuration = time.Second
-	var batchTimestamp int64
-	if request.CloseTimestamp-request.StartTimestamp < minWorkflowDuration.Nanoseconds() {
-		batchTimestamp = request.StartTimestamp + minWorkflowDuration.Nanoseconds()
+	var batchTimestamp time.Time
+	if request.CloseTime.Sub(request.StartTime) < minWorkflowDuration {
+		batchTimestamp = request.StartTime.Add(minWorkflowDuration)
 	} else {
-		batchTimestamp = request.CloseTimestamp
+		batchTimestamp = request.CloseTime
 	}
 
-	batch = batch.WithTimestamp(p.UnixNanoToDBTimestamp(batchTimestamp))
+	batch = batch.WithTimestamp(p.UnixMilliseconds(batchTimestamp))
 	err := v.session.ExecuteBatch(batch)
 	return gocql.ConvertError("RecordWorkflowExecutionClosed", err)
 }
@@ -256,11 +256,13 @@ func (v *cassandraVisibilityPersistence) UpsertWorkflowExecution(request *p.Inte
 func (v *cassandraVisibilityPersistence) ListOpenWorkflowExecutions(
 	request *p.ListWorkflowExecutionsRequest,
 ) (*p.InternalListWorkflowExecutionsResponse, error) {
-	query := v.session.Query(templateGetOpenWorkflowExecutions,
-		request.NamespaceID,
-		namespacePartition,
-		p.UnixNanoToDBTimestamp(request.EarliestStartTime),
-		p.UnixNanoToDBTimestamp(request.LatestStartTime)).Consistency(v.lowConslevel)
+	query := v.session.
+		Query(templateGetOpenWorkflowExecutions,
+			request.NamespaceID,
+			namespacePartition,
+			p.UnixMilliseconds(request.EarliestStartTime),
+			p.UnixMilliseconds(request.LatestStartTime)).
+		Consistency(v.lowConslevel)
 	iter := query.PageSize(request.PageSize).PageState(request.NextPageToken).Iter()
 
 	response := &p.InternalListWorkflowExecutionsResponse{}
@@ -282,12 +284,14 @@ func (v *cassandraVisibilityPersistence) ListOpenWorkflowExecutions(
 
 func (v *cassandraVisibilityPersistence) ListOpenWorkflowExecutionsByType(
 	request *p.ListWorkflowExecutionsByTypeRequest) (*p.InternalListWorkflowExecutionsResponse, error) {
-	query := v.session.Query(templateGetOpenWorkflowExecutionsByType,
-		request.NamespaceID,
-		namespacePartition,
-		p.UnixNanoToDBTimestamp(request.EarliestStartTime),
-		p.UnixNanoToDBTimestamp(request.LatestStartTime),
-		request.WorkflowTypeName).Consistency(v.lowConslevel)
+	query := v.session.
+		Query(templateGetOpenWorkflowExecutionsByType,
+			request.NamespaceID,
+			namespacePartition,
+			p.UnixMilliseconds(request.EarliestStartTime),
+			p.UnixMilliseconds(request.LatestStartTime),
+			request.WorkflowTypeName).
+		Consistency(v.lowConslevel)
 	iter := query.PageSize(request.PageSize).PageState(request.NextPageToken).Iter()
 
 	response := &p.InternalListWorkflowExecutionsResponse{}
@@ -309,12 +313,14 @@ func (v *cassandraVisibilityPersistence) ListOpenWorkflowExecutionsByType(
 
 func (v *cassandraVisibilityPersistence) ListOpenWorkflowExecutionsByWorkflowID(
 	request *p.ListWorkflowExecutionsByWorkflowIDRequest) (*p.InternalListWorkflowExecutionsResponse, error) {
-	query := v.session.Query(templateGetOpenWorkflowExecutionsByID,
-		request.NamespaceID,
-		namespacePartition,
-		p.UnixNanoToDBTimestamp(request.EarliestStartTime),
-		p.UnixNanoToDBTimestamp(request.LatestStartTime),
-		request.WorkflowID).Consistency(v.lowConslevel)
+	query := v.session.
+		Query(templateGetOpenWorkflowExecutionsByID,
+			request.NamespaceID,
+			namespacePartition,
+			p.UnixMilliseconds(request.EarliestStartTime),
+			p.UnixMilliseconds(request.LatestStartTime),
+			request.WorkflowID).
+		Consistency(v.lowConslevel)
 	iter := query.PageSize(request.PageSize).PageState(request.NextPageToken).Iter()
 
 	response := &p.InternalListWorkflowExecutionsResponse{}
@@ -336,11 +342,13 @@ func (v *cassandraVisibilityPersistence) ListOpenWorkflowExecutionsByWorkflowID(
 
 func (v *cassandraVisibilityPersistence) ListClosedWorkflowExecutions(
 	request *p.ListWorkflowExecutionsRequest) (*p.InternalListWorkflowExecutionsResponse, error) {
-	query := v.session.Query(templateGetClosedWorkflowExecutions,
-		request.NamespaceID,
-		namespacePartition,
-		p.UnixNanoToDBTimestamp(request.EarliestStartTime),
-		p.UnixNanoToDBTimestamp(request.LatestStartTime)).Consistency(v.lowConslevel)
+	query := v.session.
+		Query(templateGetClosedWorkflowExecutions,
+			request.NamespaceID,
+			namespacePartition,
+			p.UnixMilliseconds(request.EarliestStartTime),
+			p.UnixMilliseconds(request.LatestStartTime)).
+		Consistency(v.lowConslevel)
 	iter := query.PageSize(request.PageSize).PageState(request.NextPageToken).Iter()
 
 	response := &p.InternalListWorkflowExecutionsResponse{}
@@ -362,12 +370,14 @@ func (v *cassandraVisibilityPersistence) ListClosedWorkflowExecutions(
 
 func (v *cassandraVisibilityPersistence) ListClosedWorkflowExecutionsByType(
 	request *p.ListWorkflowExecutionsByTypeRequest) (*p.InternalListWorkflowExecutionsResponse, error) {
-	query := v.session.Query(templateGetClosedWorkflowExecutionsByType,
-		request.NamespaceID,
-		namespacePartition,
-		p.UnixNanoToDBTimestamp(request.EarliestStartTime),
-		p.UnixNanoToDBTimestamp(request.LatestStartTime),
-		request.WorkflowTypeName).Consistency(v.lowConslevel)
+	query := v.session.
+		Query(templateGetClosedWorkflowExecutionsByType,
+			request.NamespaceID,
+			namespacePartition,
+			p.UnixMilliseconds(request.EarliestStartTime),
+			p.UnixMilliseconds(request.LatestStartTime),
+			request.WorkflowTypeName).
+		Consistency(v.lowConslevel)
 	iter := query.PageSize(request.PageSize).PageState(request.NextPageToken).Iter()
 
 	response := &p.InternalListWorkflowExecutionsResponse{}
@@ -389,12 +399,14 @@ func (v *cassandraVisibilityPersistence) ListClosedWorkflowExecutionsByType(
 
 func (v *cassandraVisibilityPersistence) ListClosedWorkflowExecutionsByWorkflowID(
 	request *p.ListWorkflowExecutionsByWorkflowIDRequest) (*p.InternalListWorkflowExecutionsResponse, error) {
-	query := v.session.Query(templateGetClosedWorkflowExecutionsByID,
-		request.NamespaceID,
-		namespacePartition,
-		p.UnixNanoToDBTimestamp(request.EarliestStartTime),
-		p.UnixNanoToDBTimestamp(request.LatestStartTime),
-		request.WorkflowID).Consistency(v.lowConslevel)
+	query := v.session.
+		Query(templateGetClosedWorkflowExecutionsByID,
+			request.NamespaceID,
+			namespacePartition,
+			p.UnixMilliseconds(request.EarliestStartTime),
+			p.UnixMilliseconds(request.LatestStartTime),
+			request.WorkflowID).
+		Consistency(v.lowConslevel)
 	iter := query.PageSize(request.PageSize).PageState(request.NextPageToken).Iter()
 
 	response := &p.InternalListWorkflowExecutionsResponse{}
@@ -416,12 +428,14 @@ func (v *cassandraVisibilityPersistence) ListClosedWorkflowExecutionsByWorkflowI
 
 func (v *cassandraVisibilityPersistence) ListClosedWorkflowExecutionsByStatus(
 	request *p.ListClosedWorkflowExecutionsByStatusRequest) (*p.InternalListWorkflowExecutionsResponse, error) {
-	query := v.session.Query(templateGetClosedWorkflowExecutionsByStatus,
-		request.NamespaceID,
-		namespacePartition,
-		p.UnixNanoToDBTimestamp(request.EarliestStartTime),
-		p.UnixNanoToDBTimestamp(request.LatestStartTime),
-		request.Status).Consistency(v.lowConslevel)
+	query := v.session.
+		Query(templateGetClosedWorkflowExecutionsByStatus,
+			request.NamespaceID,
+			namespacePartition,
+			p.UnixMilliseconds(request.EarliestStartTime),
+			p.UnixMilliseconds(request.LatestStartTime),
+			request.Status).
+		Consistency(v.lowConslevel)
 	iter := query.PageSize(request.PageSize).PageState(request.NextPageToken).Iter()
 
 	response := &p.InternalListWorkflowExecutionsResponse{}
@@ -444,12 +458,13 @@ func (v *cassandraVisibilityPersistence) ListClosedWorkflowExecutionsByStatus(
 func (v *cassandraVisibilityPersistence) GetClosedWorkflowExecution(
 	request *p.GetClosedWorkflowExecutionRequest) (*p.InternalGetClosedWorkflowExecutionResponse, error) {
 	execution := request.Execution
-	query := v.session.Query(templateGetClosedWorkflowExecution,
-		request.NamespaceID,
-		namespacePartition,
-		execution.GetWorkflowId(),
-		execution.GetRunId(),
-	)
+	query := v.session.
+		Query(templateGetClosedWorkflowExecution,
+			request.NamespaceID,
+			namespacePartition,
+			execution.GetWorkflowId(),
+			execution.GetRunId(),
+		)
 	iter := query.Iter()
 
 	wfexecution, has := readClosedWorkflowExecutionRecord(iter)
