@@ -76,7 +76,6 @@ type Config struct {
 	GlobalNamespaceRPS           dynamicconfig.IntPropertyFnWithNamespaceFilter
 	MaxIDLengthLimit             dynamicconfig.IntPropertyFn
 	EnableClientVersionCheck     dynamicconfig.BoolPropertyFn
-	MinRetentionDays             dynamicconfig.IntPropertyFn
 	DisallowQuery                dynamicconfig.BoolPropertyFnWithNamespaceFilter
 	ShutdownDrainDuration        dynamicconfig.DurationPropertyFn
 
@@ -163,7 +162,6 @@ func NewConfig(dc *dynamicconfig.Collection, numHistoryShards int32, esIndexName
 		SearchAttributesNumberOfKeysLimit:      dc.GetIntPropertyFilteredByNamespace(dynamicconfig.SearchAttributesNumberOfKeysLimit, 100),
 		SearchAttributesSizeOfValueLimit:       dc.GetIntPropertyFilteredByNamespace(dynamicconfig.SearchAttributesSizeOfValueLimit, 2*1024),
 		SearchAttributesTotalSizeLimit:         dc.GetIntPropertyFilteredByNamespace(dynamicconfig.SearchAttributesTotalSizeLimit, 40*1024),
-		MinRetentionDays:                       dc.GetIntProperty(dynamicconfig.MinRetentionDays, namespace.MinRetentionDays),
 		VisibilityArchivalQueryMaxPageSize:     dc.GetIntProperty(dynamicconfig.VisibilityArchivalQueryMaxPageSize, 10000),
 		DisallowQuery:                          dc.GetBoolPropertyFnWithNamespaceFilter(dynamicconfig.DisallowQuery, false),
 		SendRawWorkflowHistory:                 dc.GetBoolPropertyFnWithNamespaceFilter(dynamicconfig.SendRawWorkflowHistory, false),
@@ -289,6 +287,11 @@ func NewService(
 		configs.ExecutionAPICountLimitOverride,
 	)
 
+	namespaceLogger := params.NamespaceLogger
+	namespaceLogInterceptor := interceptor.NewNamespaceLogInterceptor(
+		serviceResource.GetNamespaceCache(),
+		namespaceLogger)
+
 	kep := keepalive.EnforcementPolicy{
 		MinTime:             serviceConfig.KeepAliveMinTime(),
 		PermitWithoutStream: serviceConfig.KeepAlivePermitWithoutStream(),
@@ -310,6 +313,7 @@ func NewService(
 		grpc.KeepaliveParams(kp),
 		grpc.KeepaliveEnforcementPolicy(kep),
 		grpc.ChainUnaryInterceptor(
+			namespaceLogInterceptor.Intercept,
 			rpc.ServiceErrorInterceptor,
 			metricsInterceptor.Intercept,
 			rateLimiterInterceptor.Intercept,
