@@ -127,8 +127,8 @@ const (
 	FlagDescriptionWithAlias                  = FlagDescription + ", desc"
 	FlagOwnerEmail                            = "owner_email"
 	FlagOwnerEmailWithAlias                   = FlagOwnerEmail + ", oe"
-	FlagRetentionDays                         = "retention"
-	FlagRetentionDaysWithAlias                = FlagRetentionDays + ", rd"
+	FlagRetention                             = "retention"
+	FlagRetentionWithAlias                    = FlagRetention + ", rd"
 	FlagHistoryArchivalState                  = "history_archival_state"
 	FlagHistoryArchivalStateWithAlias         = FlagHistoryArchivalState + ", has"
 	FlagHistoryArchivalURI                    = "history_uri"
@@ -183,6 +183,7 @@ const (
 	FlagAddBadBinary                          = "add_bad_binary"
 	FlagRemoveBadBinary                       = "remove_bad_binary"
 	FlagResetType                             = "reset_type"
+	FlagResetReapplyType                      = "reset_reapply_type"
 	FlagResetPointsOnly                       = "reset_points_only"
 	FlagResetBadBinaryChecksum                = "reset_bad_binary_checksum"
 	FlagListQuery                             = "query"
