@@ -28,6 +28,7 @@ import (
 	"bufio"
 	"bytes"
 	"context"
+	"encoding/json"
 	"errors"
 	"fmt"
 	"io/ioutil"
@@ -51,9 +52,9 @@ import (
 	namespacepb "go.temporal.io/api/namespace/v1"
 	querypb "go.temporal.io/api/query/v1"
 	"go.temporal.io/api/serviceerror"
-	taskqueuepb "go.temporal.io/api/taskqueue/v1"
 	workflowpb "go.temporal.io/api/workflow/v1"
 	"go.temporal.io/api/workflowservice/v1"
+	"go.temporal.io/sdk/client"
 	sdkclient "go.temporal.io/sdk/client"
 
 	clispb "go.temporal.io/server/api/cli/v1"
@@ -64,7 +65,7 @@ import (
 	"go.temporal.io/server/common/payloads"
 	"go.temporal.io/server/common/primitives/timestamp"
 	"go.temporal.io/server/common/searchattribute"
-	"go.temporal.io/server/service/history"
+	"go.temporal.io/server/service/history/workflow"
 	"go.temporal.io/server/tools/cli/dataconverter"
 	"go.temporal.io/server/tools/cli/stringify"
 )
@@ -183,7 +184,7 @@ func RunWorkflow(c *cli.Context) {
 }
 
 func startWorkflowHelper(c *cli.Context, shouldPrintProgress bool) {
-	serviceClient := cFactory.FrontendClient(c)
+	sdkClient := getSDKClient(c)
 
 	namespace := getRequiredGlobalOption(c, FlagNamespace)
 	taskQueue := getRequiredOption(c, FlagTaskQueue)
@@ -203,51 +204,37 @@ func startWorkflowHelper(c *cli.Context, shouldPrintProgress bool) {
 		reusePolicy = enumspb.WorkflowIdReusePolicy(reusePolicyInt)
 	}
 
-	input := processJSONInput(c)
-	startRequest := &workflowservice.StartWorkflowExecutionRequest{
-		RequestId:  uuid.New(),
-		Namespace:  namespace,
-		WorkflowId: wid,
-		WorkflowType: &commonpb.WorkflowType{
-			Name: workflowType,
-		},
-		TaskQueue: &taskqueuepb.TaskQueue{
-			Name: taskQueue,
-			Kind: enumspb.TASK_QUEUE_KIND_NORMAL,
-		},
-		Input:                    input,
-		WorkflowExecutionTimeout: timestamp.DurationPtr(time.Duration(et) * time.Second),
-		WorkflowTaskTimeout:      timestamp.DurationPtr(time.Duration(dt) * time.Second),
-		Identity:                 getCliIdentity(),
-		WorkflowIdReusePolicy:    reusePolicy,
+	inputs := unmarshalInputsFromCLI(c)
+	wo := client.StartWorkflowOptions{
+		ID:                       wid,
+		TaskQueue:                taskQueue,
+		WorkflowExecutionTimeout: time.Duration(et) * time.Second,
+		WorkflowTaskTimeout:      time.Duration(dt) * time.Second,
+		WorkflowIDReusePolicy:    reusePolicy,
 	}
 	if c.IsSet(FlagCronSchedule) {
-		startRequest.CronSchedule = c.String(FlagCronSchedule)
+		wo.CronSchedule = c.String(FlagCronSchedule)
 	}
 
-	memoFields := processMemo(c)
-	if len(memoFields) != 0 {
-		startRequest.Memo = &commonpb.Memo{Fields: memoFields}
-	}
-
-	startRequest.SearchAttributes = processSearchAttr(c)
+	wo.Memo = unmarshalMemoFromCLI(c)
+	wo.SearchAttributes = unmarshalSearchAttrFromCLI(c)
 
 	startFn := func() {
 		tcCtx, cancel := newContext(c)
 		defer cancel()
-		resp, err := serviceClient.StartWorkflowExecution(tcCtx, startRequest)
+		resp, err := sdkClient.ExecuteWorkflow(tcCtx, wo, workflowType, inputs...)
 
 		if err != nil {
 			ErrorAndExit("Failed to create workflow.", err)
 		} else {
-			fmt.Printf("Started Workflow Id: %s, run Id: %s\n", wid, resp.GetRunId())
+			fmt.Printf("Started Workflow Id: %s, run Id: %s\n", wid, resp.GetRunID())
 		}
 	}
 
 	runFn := func() {
 		tcCtx, cancel := newContextForLongPoll(c)
 		defer cancel()
-		resp, err := serviceClient.StartWorkflowExecution(tcCtx, startRequest)
+		resp, err := sdkClient.ExecuteWorkflow(tcCtx, wo, workflowType, inputs...)
 
 		if err != nil {
 			ErrorAndExit("Failed to run workflow.", err)
@@ -258,18 +245,18 @@ func startWorkflowHelper(c *cli.Context, shouldPrintProgress bool) {
 		table := tablewriter.NewWriter(os.Stdout)
 		executionData := [][]string{
 			{"Workflow Id", wid},
-			{"Run Id", resp.GetRunId()},
+			{"Run Id", resp.GetRunID()},
 			{"Type", workflowType},
 			{"Namespace", namespace},
 			{"Task Queue", taskQueue},
-			{"Args", truncate(payloads.ToString(input))}, // in case of large input
+			{"Args", truncate(formatInputsForDisplay(inputs))}, // in case of large input
 		}
 		table.SetBorder(false)
 		table.SetColumnSeparator(":")
 		table.AppendBulk(executionData) // Add Bulk Data
 		table.Render()
 
-		printWorkflowProgress(c, wid, resp.GetRunId())
+		printWorkflowProgress(c, wid, resp.GetRunID())
 	}
 
 	if shouldPrintProgress {
@@ -279,7 +266,36 @@ func startWorkflowHelper(c *cli.Context, shouldPrintProgress bool) {
 	}
 }
 
-func processSearchAttr(c *cli.Context) *commonpb.SearchAttributes {
+func unmarshalInputsFromCLI(c *cli.Context) []interface{} {
+	jsonsRaw := readJSONInputs(c, jsonTypeInput)
+
+	var result []interface{}
+	for _, jsonRaw := range jsonsRaw {
+		if jsonRaw == nil {
+			result = append(result, nil)
+		} else {
+			var j interface{}
+			if err := json.Unmarshal(jsonRaw, &j); err != nil {
+				ErrorAndExit("Input is not valid JSON.", err)
+			}
+			result = append(result, j)
+		}
+
+	}
+
+	return result
+}
+
+func formatInputsForDisplay(inputs []interface{}) string {
+	var result []string
+	for _, input := range inputs {
+		s, _ := json.Marshal(input)
+		result = append(result, string(s))
+	}
+	return fmt.Sprintf("[%s]", strings.Join(result, ","))
+}
+
+func unmarshalSearchAttrFromCLI(c *cli.Context) map[string]interface{} {
 	sanitize := func(val string) []string {
 		trimmedVal := strings.TrimSpace(val)
 		if len(trimmedVal) == 0 {
@@ -297,29 +313,29 @@ func processSearchAttr(c *cli.Context) *commonpb.SearchAttributes {
 	if len(searchAttrKeys) == 0 {
 		return nil
 	}
-	searchAttrVals := sanitize(c.String(FlagSearchAttributesVal))
-	if len(searchAttrVals) == 0 {
+	rawSearchAttrVals := sanitize(c.String(FlagSearchAttributesVal))
+	if len(rawSearchAttrVals) == 0 {
 		return nil
 	}
 
-	if len(searchAttrKeys) != len(searchAttrVals) {
-		ErrorAndExit(fmt.Sprintf("Uneven number of search attributes keys (%d): %v and values(%d): %v.", len(searchAttrKeys), searchAttrKeys, len(searchAttrVals), searchAttrVals), nil)
+	if len(searchAttrKeys) != len(rawSearchAttrVals) {
+		ErrorAndExit(fmt.Sprintf("Uneven number of search attributes keys (%d): %v and values(%d): %v.", len(searchAttrKeys), searchAttrKeys, len(rawSearchAttrVals), rawSearchAttrVals), nil)
 	}
 
-	searchAttributesStr := make(map[string]string, len(searchAttrKeys))
-	for i, searchAttrVal := range searchAttrVals {
-		searchAttributesStr[searchAttrKeys[i]] = searchAttrVal
+	fields := make(map[string]interface{}, len(searchAttrKeys))
+
+	for i, v := range rawSearchAttrVals {
+		var j interface{}
+		if err := json.Unmarshal([]byte(v), &j); err != nil {
+			ErrorAndExit("Search attribute JSON parse error.", err)
+		}
+		fields[searchAttrKeys[i]] = j
 	}
 
-	searchAttributes, err := searchattribute.Parse(searchAttributesStr, nil)
-	if err != nil {
-		ErrorAndExit("Unable to parse search attributes.", err)
-	}
-
-	return searchAttributes
+	return fields
 }
 
-func processMemo(c *cli.Context) map[string]*commonpb.Payload {
+func unmarshalMemoFromCLI(c *cli.Context) map[string]interface{} {
 	rawMemoKey := c.String(FlagMemoKey)
 	var memoKeys []string
 	if strings.TrimSpace(rawMemoKey) != "" {
@@ -336,23 +352,23 @@ func processMemo(c *cli.Context) map[string]*commonpb.Payload {
 		ErrorAndExit("Input is not valid JSON, or JSONs concatenated with spaces/newlines.", err)
 	}
 
-	var memoValues []string
+	var memoValues []interface{}
 
 	var sc fastjson.Scanner
 	sc.Init(rawMemoValue)
 	for sc.Next() {
-		memoValues = append(memoValues, sc.Value().String())
+		memoValues = append(memoValues, sc.Value())
 	}
 	if err := sc.Error(); err != nil {
-		ErrorAndExit("Parse json error.", err)
+		ErrorAndExit("Memo JSON parse error.", err)
 	}
 	if len(memoKeys) != len(memoValues) {
 		ErrorAndExit("Number of memo keys and values are not equal.", nil)
 	}
 
-	fields := map[string]*commonpb.Payload{}
+	fields := make(map[string]interface{}, len(memoKeys))
 	for i, key := range memoKeys {
-		fields[key] = payload.EncodeString(memoValues[i])
+		fields[key] = memoValues[i]
 	}
 	return fields
 }
@@ -363,7 +379,7 @@ func getPrintableMemo(memo *commonpb.Memo) string {
 		var memo string
 		err := payload.Decode(v, &memo)
 		if err != nil {
-			ErrorAndExit("Memo has incoorect formtat.", err)
+			ErrorAndExit("Memo has incorrect format.", err)
 		}
 
 		_, _ = fmt.Fprintf(buf, "%s=%s\n", k, memo)
@@ -1369,8 +1385,12 @@ func ResetWorkflow(c *cli.Context) {
 	if !ok && eventID <= 0 {
 		ErrorAndExit(fmt.Sprintf("must specify either valid event_id or reset_type (one of %s)", strings.Join(mapKeysToArray(resetTypesMap), ", ")), nil)
 	}
-	if ok && len(extraForResetType) > 0 {
-		getRequiredOption(c, extraForResetType)
+	if ok && len(extraForResetType.(string)) > 0 {
+		getRequiredOption(c, extraForResetType.(string))
+	}
+	resetReapplyType := c.String(FlagResetReapplyType)
+	if _, ok := resetReapplyTypesMap[resetReapplyType]; !ok {
+		ErrorAndExit(fmt.Sprintf("must specify valid reset reapply type: %v", strings.Join(mapKeysToArray(resetReapplyTypesMap), ", ")), nil)
 	}
 
 	ctx, cancel := newContext(c)
@@ -1396,6 +1416,7 @@ func ResetWorkflow(c *cli.Context) {
 		Reason:                    fmt.Sprintf("%v:%v", getCurrentUserFromEnv(), reason),
 		WorkflowTaskFinishEventId: workflowTaskFinishID,
 		RequestId:                 uuid.New(),
+		ResetReapplyType:          resetReapplyTypesMap[resetReapplyType].(enumspb.ResetReapplyType),
 	})
 	if err != nil {
 		ErrorAndExit("reset failed", err)
@@ -1456,8 +1477,8 @@ func ResetInBatch(c *cli.Context) {
 	extraForResetType, ok := resetTypesMap[resetType]
 	if !ok {
 		ErrorAndExit("Not supported reset type", nil)
-	} else if len(extraForResetType) > 0 {
-		getRequiredOption(c, extraForResetType)
+	} else if len(extraForResetType.(string)) > 0 {
+		getRequiredOption(c, extraForResetType.(string))
 	}
 
 	batchResetParams := batchResetParamsType{
@@ -1786,7 +1807,7 @@ func getBadWorkflowTaskCompletedID(ctx context.Context, namespace, wid, rid, bin
 		return "", 0, printErrorAndReturn("DescribeWorkflowExecution failed", err)
 	}
 
-	_, p := history.FindAutoResetPoint(clock.NewRealTimeSource(), &namespacepb.BadBinaries{
+	_, p := workflow.FindAutoResetPoint(clock.NewRealTimeSource(), &namespacepb.BadBinaries{
 		Binaries: map[string]*namespacepb.BadBinaryInfo{
 			binChecksum: {},
 		},
